;; Generated package description from yasnippet.el  -*- no-byte-compile: t -*-
(define-package "yasnippet" "0.14.3" "Yet another snippet extension for Emacs" '((cl-lib "0.5") (emacs "24.4")) :commit "dd570a6b22364212fff9769cbf4376bdbd7a63c5" :maintainer '("Noam Postavsky" . "npostavs@gmail.com") :keywords '("convenience" "emulation") :url "http://github.com/joaotavora/yasnippet")
